@@ -101,6 +101,11 @@ VALID_ADV_VALUES = {0, 1}
 
 AUTH_FAILURE_TO_START_REAUTH = 5
 
+NO_BATTERY_SUPPORT_MODELS = {
+    "SL-103",  # Linus L2
+    "CERES",  # Smart code handle
+}
+
 
 def operation_lock(func: WrapFuncType) -> WrapFuncType:
     """Define a wrapper to only allow a single operation at a time."""
@@ -307,7 +312,10 @@ class PushLock:
     @property
     def address(self) -> str:
         """Get the address of the lock."""
-        return self._ble_device.address if self._ble_device else self._address
+        if self._ble_device:
+            return self._ble_device.address
+        assert self._address is not None  # nosec
+        return self._address
 
     @property
     def door_status(self) -> DoorStatus:
@@ -564,12 +572,17 @@ class PushLock:
             max_attempts = 1 if self._first_update_future else MAX_CONNECT_ATTEMPTS
             try:
                 await self._client.connect(max_attempts)
-            except Exception as ex:
+            except BaseException as ex:  # Might be cancelled
                 _LOGGER.debug(
                     "%s: Failed to connect due to %s, forcing disconnect", self.name, ex
                 )
-                await self._client.disconnect()
-                raise
+                try:
+                    await self._client.disconnect()
+                except Exception:
+                    _LOGGER.exception(
+                        "%s: Failed to disconnect after failed connect", self.name
+                    )
+                raise ex
             self._next_disconnect_delay = self._idle_disconnect_delay
             self._reset_disconnect_timer()
             self._seen_this_session.clear()
@@ -707,12 +720,19 @@ class PushLock:
         lock = await self._ensure_connected()
         if not self._lock_info:
             self._lock_info = await lock.lock_info()
+            _LOGGER.debug("Obtained lock info: %s", self._lock_info)
         # Asking for battery first seems to be reduce the chance of the lock
         # getting into a bad state.
         state = self._get_current_state()
         made_request = False
 
-        if BatteryState not in self._seen_this_session:
+        needs_battery_workaround = self._lock_info.model in NO_BATTERY_SUPPORT_MODELS
+        _LOGGER.debug(
+            "Needs battery workaround model %s: %s",
+            self._lock_info.model,
+            needs_battery_workaround,
+        )
+        if not needs_battery_workaround and BatteryState not in self._seen_this_session:
             made_request = True
             battery_state = await lock.battery()
             _AUTH_FAILURE_HISTORY.auth_success(self.address)
@@ -1034,6 +1054,11 @@ class PushLock:
         except asyncio.TimeoutError as ex:
             self._set_update_state(ex)
             _LOGGER.exception("%s: Timed out updating", self.name)
+        except BleakNotFoundError as ex:
+            wrapped_bleak_exc = BluetoothError(str(ex))
+            wrapped_bleak_exc.__cause__ = ex
+            self._set_update_state(wrapped_bleak_exc)
+            _LOGGER.debug("%s: not found error updating", self.name, exc_info=True)
         except BleakError as ex:
             wrapped_bleak_exc = BluetoothError(str(ex))
             wrapped_bleak_exc.__cause__ = ex
